function C = msmt_classify(T,points)
% MSMT_CLASSIFY determines whether a point or set of points is/are elements
%	of set A or set B.
%
%	C = msmt_classify(T,points)
%
%	T: matrix representing the decision matrix T, generated by MSMT 
%		algorithm.
%	points: if classifying one point, points is a vector representing
%		that point
%		if classifying more than one point, points is a matrix
%		where each row is an individual point.
%	C: matrix structured as follow:
%	   for point i:
%		row i of C is as follows:
%		C(i) = 'A' if point i is in set A
%		C(i) = 'B' if point i is in set B

global n

results = msmt_split(T,points);

for i = 1:size(results,2)

	if (results(i) == 0)
		D(i) = 'A';
	else
		D(i) = 'B';
	end
end
C = D';

